@@ -265,7 +265,7 @@ def desktop_environment():
     env = 'unknown'
     if desktop_session is not None:
         desktop_session = desktop_session.lower()
-        if desktop_session in ['gnome', 'unity', 'budgie-desktop', 'cinnamon', 'mate', 'xfce4', 'lxde', 'pantheon', 'fluxbox', 'blackbox', 'openbox', 'icewm', 'jwm', 'afterstep', 'trinity', 'kde']:
+        if desktop_session in ['gnome', 'unity', 'budgie-desktop', 'cinnamon', 'mate', 'xfce4', 'lxde', 'pantheon', 'fluxbox', 'blackbox', 'openbox', 'icewm', 'jwm', 'afterstep', 'trinity', 'kde', 'hyprland']:
             env = desktop_session
         elif desktop_session.startswith('xubuntu') or (current_desktop is not None and 'xfce' in current_desktop):
             env = 'xfce'
@@ -370,7 +370,7 @@ def initialize_safeeyes():
 
     # Copy the safeeyes.json
     shutil.copy2(SYSTEM_CONFIG_FILE_PATH, CONFIG_FILE_PATH)
-    os.chmod(CONFIG_FILE_PATH, 0o777)
+    os.chmod(CONFIG_FILE_PATH, 0o666)
 
     create_user_stylesheet_if_missing()
 
@@ -385,7 +385,7 @@ def create_user_stylesheet_if_missing():
     # Copy the new style sheet
     if not os.path.isfile(STYLE_SHEET_PATH):
         shutil.copy2(SYSTEM_STYLE_SHEET_PATH, STYLE_SHEET_PATH)
-        os.chmod(STYLE_SHEET_PATH, 0o777)
+        os.chmod(STYLE_SHEET_PATH, 0o666)
 
 def create_startup_entry(force=False):
     """
@@ -493,8 +493,8 @@ def reset_config():
     shutil.copy2(SYSTEM_STYLE_SHEET_PATH, STYLE_SHEET_PATH)
     
     # Add write permission (e.g. if original file was stored in /nix/store)
-    os.chmod(CONFIG_FILE_PATH, 0o777)
-    os.chmod(STYLE_SHEET_PATH, 0o777)
+    os.chmod(CONFIG_FILE_PATH, 0o666)
+    os.chmod(STYLE_SHEET_PATH, 0o666)
 
     create_startup_entry()
 
@@ -505,7 +505,7 @@ def replace_style_sheet():
     """
     delete(STYLE_SHEET_PATH)
     shutil.copy2(SYSTEM_STYLE_SHEET_PATH, STYLE_SHEET_PATH)
-    os.chmod(STYLE_SHEET_PATH, 0o777)
+    os.chmod(STYLE_SHEET_PATH, 0o666)
 
 
 def initialize_logging(debug):
